@@ -2,6 +2,6 @@ from .validator import Validator
 from .simple import Required, IsNumber
 from .dates import IsDate, IsTime, Before, After, BeforeNow, AfterNow
 from .values import LongerThan, ShorterThan, LessThan, MoreThan, InRange
-from .patterns import Match, ValidEmail, ValidURL, IsColor
+from .patterns import Match, ValidEmail, ValidURL, ValidColor, IsColor
 
 from .form_wide import FormValidator, AreEqual, AtLeastOne, ValidSplitDate
